.. spike documentation master file, created by
   sphinx-quickstart on Tue Dec  2 12:43:04 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SPIKE documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 3
   
   rst/introduction.rst
   rst/tutorial.rst
   rst/code.rst
   rst/licenses.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

